==> yieldplotlib-0.5.0.tar.gz: yieldplotlib-0.5.0/docs/user/parameters_table.md <==
| Parameter               | Description                                                          |
|:------------------------|:---------------------------------------------------------------------|
| Bmag                    | B-band magnitude                                                     |
| Dec                     | Declination                                                          |
| Hmag                    | H-band magnitude                                                     |
| Imag                    | I-band magnitude                                                     |
| Jmag                    | J-band magnitude                                                     |
| Kmag                    | K-band magnitude                                                     |
| MV                      | Absolute magnitude of the target star.                               |
| Ms                      | Mass in solar masses                                                 |
| R                       | Spectral resolution for detection                                    |
| RA                      | Right Ascension                                                      |
| Rmag                    | R-band magnitude                                                     |
| Umag                    | Ultraviolet magnitude                                                |
| Vmag                    | V-band magnitude                                                     |
| angdiam                 | Angular diameter in milliarcseconds                                  |
| blind_comp_det          | Blind (or single-visit) completeness for the detection mode          |
| blind_comp_spec         | Blind (or single-visit) completeness for the spectroscopy mode       |
| cic                     | Detector clock induced charge                                        |
| core_thruput            | nan                                                                  |
| coron_bw                | Bandwidth of the coronagraph                                         |
| coron_lam               | Central working wavelength for the coronagraph                       |
| coron_optics_thorughput | Throughput of the coronagraph optics                                 |
| dark_current            | Detector dark current                                                |
| exp_time_char           | Total integration time for characterizations per star.               |
| exp_time_det            | Total integration time for detections per star.                      |
| instruments             | List of all instrument specifications used (EXOSIMS only)            |
| istar                   | nan                                                                  |
| iwa                     | Inner working angle of the coronagraph                               |
| modes                   | List of all of the observing modes used (EXOSIMS only)               |
| obs_lam                 | Observing wavelength for detection mode                              |
| obs_target_ind          | Star index identifier.                                               |
| obs_target_name         | Name of the target star or planet.                                   |
| optics_throughput       | Throughout of the optics                                             |
| owa                     | Outer working angle of the coronagraph                               |
| pixel_scale             | Detector pixel scale                                                 |
| pupil_diam              | Circumscribed diameter of the telescope (m)                          |
| qe                      | Quantum efficiency                                                   |
| read_noise              | Detector read noise                                                  |
| sc_R                    | Spectral resolution for characterization                             |
| sc_cic                  | Spectrigraph clock induced charge                                    |
| sc_dark_current         | Spectrograph dark current                                            |
| sc_obs_lam              | Observing wavelength for characterization mode                       |
| sc_optics_throughput    | Throughput of the optics for spectroscopy                            |
| sc_pixel_scale          | Spectrograph pixel scale                                             |
| sc_qe                   | Quantum efficiency for spectroscopy                                  |
| sc_read_noise           | Spectrograph read noise                                              |
| sc_snr                  | Required signal to noise ratio for characterization                  |
| sc_texp                 | Single exposure time for spectroscopic observation                   |
| snr                     | Required signal to noise ratio for detection                         |
| star_L                  | Luminosity of the star (in solar luminosities).                      |
| star_comp_det           | Cumulative Earth-like planet detections per star.                    |
| star_dist               | Distance to the star (in parsecs).                                   |
| star_id                 | Star index identifier.                                               |
| star_name               | Name of the star.                                                    |
| star_spec               | Spectral type of the star.                                           |
| systs                   | List of all of the starlight suppression systems used (EXOSIMS only) |
| texp                    | Single exposure time                                                 |
| yield_cold_jupiter      | Yield of cold Jupiters                                               |
| yield_cold_neptune      | Yield of cold Neptunes                                               |
| yield_cold_rocky        | Yield of cold rocky planets                                          |
| yield_cold_sub_neptune  | Yield of cold sub-Neptunes                                           |
| yield_cold_super_earth  | Yield of cold Super-Earths                                           |
| yield_earth             | Yield of Earth-like exoplanet candidates                             |
| yield_hot_jupiter       | Yield of hot Jupiters                                                |
| yield_hot_neptune       | Yield of hot Neptunes                                                |
| yield_hot_rocky         | Yield of hot rocky planets                                           |
| yield_hot_sub_neptune   | Yield of hot sub-Neptunes                                            |
| yield_hot_super_earth   | Yield of hot Super-Earths                                            |
| yield_warm_jupiter      | Yield of warm Jupiters                                               |
| yield_warm_neptune      | Yield of warm Neptunes                                               |
| yield_warm_rocky        | Yield of warm rocky planets                                          |
| yield_warm_sub_neptune  | Yield of warm sub-Neptunes                                           |
| yield_warm_super_earth  | Yield of warm Super-Earths                                           |

==> yieldplotlib-1.1.1.tar.gz: yieldplotlib-1.1.1/docs/user/parameters_table.md <==
| Parameter               | Description                                                          |
|:------------------------|:---------------------------------------------------------------------|
| Bmag                    | B-band magnitude                                                     |
| Dec                     | Declination                                                          |
| Hmag                    | H-band magnitude                                                     |
| Imag                    | I-band magnitude                                                     |
| Jmag                    | J-band magnitude                                                     |
| Kmag                    | K-band magnitude                                                     |
| MV                      | Absolute magnitude of the target star.                               |
| Ms                      | Mass (Solar masses)                                                  |
| R                       | Spectral resolution for detection                                    |
| RA                      | Right Ascension                                                      |
| Rmag                    | R-band magnitude                                                     |
| Umag                    | Ultraviolet magnitude                                                |
| Vmag                    | V-band magnitude                                                     |
| angdiam                 | Angular diameter (mas)                                               |
| blind_comp_det          | Blind (or single-visit) completeness for the detection mode          |
| blind_comp_spec         | Blind (or single-visit) completeness for the spectroscopy mode       |
| cic                     | Detector clock induced charge                                        |
| core_thruput            | Core throughput of the coronagraph                                   |
| coron_bw                | Bandwidth of the coronagraph                                         |
| coron_lam               | Central working wavelength for the coronagraph                       |
| coron_optics_thorughput | Throughput of the coronagraph optics                                 |
| dark_current            | Detector dark current                                                |
| exp_time_char           | Total integration time for characterizations per star.               |
| exp_time_det            | Total integration time for detections per star.                      |
| instruments             | List of all instrument specifications used (EXOSIMS only)            |
| istar                   | Offset PSF peak at the stellocentric distance of the planet          |
| iwa                     | Inner working angle of the coronagraph                               |
| modes                   | List of all of the observing modes used (EXOSIMS only)               |
| obs_lam                 | Observing wavelength for detection mode                              |
| obs_target_ind          | Star index identifier.                                               |
| obs_target_name         | Name of the target star or planet.                                   |
| optics_throughput       | Throughout of the optics                                             |
| owa                     | Outer working angle of the coronagraph                               |
| pixel_scale             | Detector pixel scale                                                 |
| pupil_diam              | Circumscribed diameter of the telescope (m)                          |
| qe                      | Quantum efficiency                                                   |
| read_noise              | Detector read noise                                                  |
| sc_R                    | Spectral resolution for characterization                             |
| sc_cic                  | Spectrograph clock induced charge                                    |
| sc_dark_current         | Spectrograph dark current                                            |
| sc_obs_lam              | Observing wavelength for characterization mode                       |
| sc_optics_throughput    | Throughput of the optics for spectroscopy                            |
| sc_pixel_scale          | Spectrograph pixel scale                                             |
| sc_qe                   | Quantum efficiency for spectroscopy                                  |
| sc_read_noise           | Spectrograph read noise                                              |
| sc_snr                  | Required signal to noise ratio for characterization                  |
| sc_texp                 | Single exposure time for spectroscopic observation                   |
| snr                     | Required signal to noise ratio for detection                         |
| star_L                  | Luminosity of the star (Solar luminosities).                         |
| star_comp_det           | Cumulative Earth-like planet detections per star.                    |
| star_dist               | Distance to the star (in parsecs).                                   |
| star_id                 | Star index identifier.                                               |
| star_name               | Name of the star.                                                    |
| star_spec               | Spectral type of the star.                                           |
| systs                   | List of all of the starlight suppression systems used (EXOSIMS only) |
| texp                    | Single exposure time                                                 |
| yield_cold_jupiter      | Yield of cold Jupiters                                               |
| yield_cold_neptune      | Yield of cold Neptunes                                               |
| yield_cold_rocky        | Yield of cold rocky planets                                          |
| yield_cold_sub_neptune  | Yield of cold sub-Neptunes                                           |
| yield_cold_super_earth  | Yield of cold Super-Earths                                           |
| yield_earth             | Yield of Earth-like exoplanet candidates                             |
| yield_hot_jupiter       | Yield of hot Jupiters                                                |
| yield_hot_neptune       | Yield of hot Neptunes                                                |
| yield_hot_rocky         | Yield of hot rocky planets                                           |
| yield_hot_sub_neptune   | Yield of hot sub-Neptunes                                            |
| yield_hot_super_earth   | Yield of hot Super-Earths                                            |
| yield_warm_jupiter      | Yield of warm Jupiters                                               |
| yield_warm_neptune      | Yield of warm Neptunes                                               |
| yield_warm_rocky        | Yield of warm rocky planets                                          |
| yield_warm_sub_neptune  | Yield of warm sub-Neptunes                                           |
| yield_warm_super_earth  | Yield of warm Super-Earths                                           |
